package pod_index_models

import (
	"database/sql"
	"database/sql/driver"
	"reflect"
)

type NullInt64 sql.NullInt64

func (i NullInt64) Value() (driver.Value, error) {
	return i, nil
}

func (ni *NullInt64) Scan(value interface{}) error {
	var i sql.NullInt64
	if value == "" {
		// This is an empty string in an int.  Make Valid false.
		*ni = NullInt64{i.Int64, false}
	} else {
		if err := i.Scan(value); err != nil {
			return err
		}
		// if nil the make Valid false
		if reflect.TypeOf(value) == nil {
			*ni = NullInt64{i.Int64, false}
		} else {
			*ni = NullInt64{i.Int64, true}
		}
	}
	return nil
}

type Podcasts struct {
	ID                      int       `gorm:"column:id;primaryKey"`
	URL                     string    `gorm:"column:url;uniqueIndex;not null"`
	Title                   string    `gorm:"column:title;not null"`
	LastUpdate              int       `gorm:"column:lastUpdate"`
	Link                    string    `gorm:"column:link;not null"`
	LastHttpStatus          int       `gorm:"column:lastHttpStatus"`
	Dead                    int       `gorm:"column:dead"`
	Contenttype             string    `gorm:"column:contentType;not null"`
	ItunesId                NullInt64 `gorm:"column:itunesId"`
	OriginalUrl             string    `gorm:"column:originalUrl;not null"`
	ItunesAuthor            string    `gorm:"column:itunesAuthor;not null"`
	ItunesOwnerName         string    `gorm:"column:itunesOwnerName;not null"`
	Explicit                int       `gorm:"column:explicit"`
	ImageUrl                string    `gorm:"column:imageUrl;not null"`
	ItunesType              string    `gorm:"column:itunesType;not null"`
	Generator               string    `gorm:"column:generator;not null"`
	NewestItemPubdate       int       `gorm:"column:newestItemPubdate"`
	Language                string    `gorm:"column:language;not null"`
	OldestItemPubdate       int       `gorm:"column:oldestItemPubdate"`
	EpisodeCount            int       `gorm:"column:episodeCount"`
	PopularityScore         int       `gorm:"column:popularityScore"`
	Priority                int       `gorm:"column:priority"`
	CreatedOn               int       `gorm:"column:createdOn"`
	UpdateFrequency         int       `gorm:"column:updateFrequency"`
	Chash                   string    `gorm:"column:chash;not null"`
	Host                    string    `gorm:"column:host;not null"`
	NewestEnclosureUrl      string    `gorm:"column:newestEnclosureUrl;not null"`
	PodcastGuid             string    `gorm:"column:podcastGuid;not null"`
	Description             string    `gorm:"column:description;not null"`
	Category1               string    `gorm:"column:category1;not null"`
	Category2               string    `gorm:"column:category2;not null"`
	Category3               string    `gorm:"column:category3;not null"`
	Category4               string    `gorm:"column:category4;not null"`
	Category5               string    `gorm:"column:category5;not null"`
	Category6               string    `gorm:"column:category6;not null"`
	Category7               string    `gorm:"column:category7;not null"`
	Category8               string    `gorm:"column:category8;not null"`
	Category9               string    `gorm:"column:category9;not null"`
	Category10              string    `gorm:"column:category10;not null"`
	NewestEnclosureDuration NullInt64 `gorm:"column:newestEnclosureDuration"`
}
